# Generated by Django 1.10 on 2016-08-19 20:37

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("note", "0002_auto_20160818_2104"),
    ]

    operations = [
        migrations.AlterField(
            model_name="note",
            name="date",
            field=models.DateTimeField(
                default=django.utils.timezone.now, verbose_name="Date"
            ),
        ),
    ]
