# Generated by Django 1.10 on 2016-08-25 23:37

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("order", "0006_auto_20160803_2217"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="order_item",
            name="component",
        ),
    ]
