# Generated by Django 1.11.29 on 2020-10-30 19:40

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("billing", "0003_auto_20161122_0515"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="billing",
            options={"ordering": ["-billing_year", "-billing_month"]},
        ),
    ]
