# Generated by Django 1.10 on 2016-11-22 04:58

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("billing", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="billing",
            name="total_amount",
            field=models.DecimalField(
                decimal_places=2, max_digits=8, verbose_name="total_amount"
            ),
        ),
    ]
