{% load i18n %}
<h4 class="ui dividing header">{% trans 'Meal status' %}</h4>

<div class="field">
    <div class="ui ten wide toggle checkbox">
        {{ form.status }}
        <label>{{ form.status.label }}
            <i class="help-text question yellow icon link" data-content="{{ form.status.help_text }}"></i>
        </label>
    </div>
</div>

<h4 class="ui dividing header">{% trans 'Delivery' %}</h4>

<div class="field" id="dietary_restriction-delivery_type">
  <label>{{ form.delivery_type.label }}</label>
    {{ form.delivery_type }}
</div>

<div class="field" id="form-meals-schedule">
  <label>{{ form.meals_schedule.label }}</label>
    {{ form.meals_schedule }}
</div>

<div class="field">
  <label class="inline">{{ form.meal_default.label }}</label>
    {{ form.meal_default }}
</div>


<h4 class="ui dividing header">{% trans 'Food preferences' %}</h4>

<div class="field">
  <label class="inline">{% trans 'Meal defaults' %}</label>
{% include 'client/partials/forms/meal_defaults.html'%}
</div>

<div class="field">
    <label>{{ form.restrictions.label }}</label>
    {{ form.restrictions }}
</div>

<div class="field">
    <label>{{ form.food_preparation.label }}</label>
    {{ form.food_preparation }}
</div>

<div class="field">
    <label>{{ form.ingredient_to_avoid.label }}</label>
      {{ form.ingredient_to_avoid }}
</div>

<div class="field">
    <label>{{ form.dish_to_avoid.label }}</label>
      {{ form.dish_to_avoid }}
</div>
