# Generated by Django 1.9.7 on 2016-07-26 17:03

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("member", "0006_client_meal_default_week"),
    ]

    operations = [
        migrations.AddField(
            model_name="address",
            name="distance",
            field=models.DecimalField(
                blank=True, decimal_places=6, max_digits=9, null=True
            ),
        ),
        migrations.AddField(
            model_name="address",
            name="lat",
            field=models.DecimalField(
                blank=True, decimal_places=6, max_digits=9, null=True
            ),
        ),
        migrations.AddField(
            model_name="address",
            name="lon",
            field=models.DecimalField(
                blank=True, decimal_places=6, max_digits=9, null=True
            ),
        ),
    ]
