# Generated by Django 1.10 on 2016-09-12 15:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("order", "0007_remove_order_item_component"),
    ]

    operations = [
        migrations.AlterField(
            model_name="order",
            name="client",
            field=models.ForeignKey(
                default="",
                on_delete=django.db.models.deletion.CASCADE,
                related_name="client_order",
                to="member.Client",
                verbose_name="client",
            ),
        ),
    ]
