# Generated by Django 1.11.29 on 2021-07-09 18:21

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("note", "0011_auto_20170419_1109"),
    ]

    operations = [
        migrations.AddField(
            model_name="note",
            name="is_deleted",
            field=models.BooleanField(default=False, verbose_name="Is deleted"),
        ),
    ]
