{% load i18n %}
<div class="ui">
    <div class="ui very relaxed small divided horizontal list">
        <div class="item">
            <i class="large shipping middle aligned icon"></i>
            <div class="content">
                <a class="header">{% trans 'Delivery type' %}</a>
                <div class="description">{{ client.get_delivery_type_display }}</div>
            </div>
        </div>
        <div class="item">
            <i class="large home middle aligned icon"></i>
            <div class="content">
                <a class="header">{% trans 'Address' %}</a>
                <div class="description">{{ client.member.address.street }}</div>
            </div>
        </div>
        <div class="item">
            <i class="large phone middle aligned icon"></i>
            <div class="content">
                <a class="header">{% trans 'Home' %}</a>
                <div class="description">{{client.member.home_phone}}</div>
            </div>
        </div>
        <div class="item">
            <i class="large comment middle aligned icon"></i>
            <div class="content">
                <a class="header">{% trans 'Language' %}</a>
                <div class="description">{{client.get_language_display}}</div>
            </div>
        </div>
        <div class="item">
            <i class="large birthday middle aligned icon"></i>
            <div class="content">
                <a class="header">{{client.birthdate|date:"d F Y"}}</a>
                <div class="description">{{client.age}} {% trans "years old" %}</div>
            </div>
        </div>
    </div>
</div>
