{% load i18n %}

<div class="ui four ordered steps">
  <a class="{% if step == 'orders' %} active{% endif %} step" href="{% url 'delivery:order' %}?delivery_date={{ delivery_date.isoformat }}">
    <div class="content">
      <div class="title">{% trans 'Review orders' %}</div>
      <div class="description">{% trans 'Generate and review orders.' %}</div>
    </div>
  </a>
  <a class="{% if step == 'ingredients' %} active{% endif %} step" href="{% url 'delivery:meal' %}?delivery_date={{ delivery_date.isoformat }}">
    <div class="content">
      <div class="title">{% trans 'Ingredients' %}</div>
      <div class="description">{% trans 'Pick ingredients for the day.' %}</div>
    </div>
  </a>
  <a class="{% if step == 'kitchen_count' %} active{% endif %} step" href="{% url 'delivery:kitchen_count' %}?delivery_date={{ delivery_date.isoformat }}">
    <div class="content">
      <div class="title">{% trans 'Kitchen Count' %}</div>
      <div class="description">{% trans 'Print the kitchen count.' %}</div>
    </div>
  </a>
  <a class="{% if step == 'routes' %} active{% endif %} step" href="{% url 'delivery:routes' %}?delivery_date={{ delivery_date.isoformat }}">
    <div class="content">
      <div class="title">{% trans 'Routes' %}</div>
      <div class="description">{% trans 'Organize delivery routes.' %}</div>
    </div>
  </a>
</div>
