{% load i18n %}
{% load staticfiles %}

<div class="ui card">
    <div class="image">
        <img src="{% static 'images/katrina.jpg' %}">
    </div>
    <div class="content">
        <a class="header">{{ request.user.username }}</a>
        <div class="meta">
            <span class="date">{% trans "Joined in 2010" %}</span>
        </div>
        <div class="description">
            {% trans "Katrina is the coordinator of the clients system" %}.
        </div>
    </div>
</div>
