{% load i18n %}

<thead>
    <th class="">{% trans 'Order' %}
            <i class="help-text question grey icon link" data-content="{% trans 'A unique identifier for the order.' %}"></i>
    </th>
    <th class="">{% trans 'Client' %}
        <i class="help-text question grey icon link" data-content="{% trans 'Quickly access the client file.' %}"></i>
    </th>
    <th class="">{% trans 'Delivery Date' %}
        <i class="help-text question grey icon link" data-content="{% trans 'The delivery date planned for the order.' %}"></i>
    </th>
    <th class="">{% trans 'Route' %}
        <i class="help-text question grey icon link" data-content="{% trans 'The delivery route.' %}"></i>
    </th>
    <th class="center aligned">{% trans 'Status' %}
        <i class="help-text question grey icon link" data-content="{% trans 'Display only Ordered orders.' %}"></i>
    </th>
    <th class="center aligned">{% trans 'Amount' %}
        <i class="help-text question grey icon link" data-content="{% trans 'Total amount in $CAD.' %}"></i>
    </th>
    <th class=""></th>
  </thead>
