# Generated by Django 1.9.6 on 2016-06-14 17:36

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("order", "0001_fix161f"),
    ]

    operations = [
        migrations.AlterField(
            model_name="order_item",
            name="order",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="orders",
                to="order.Order",
                verbose_name="order",
            ),
        ),
    ]
