# Generated by Django 1.10 on 2016-11-22 05:15

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("billing", "0002_auto_20161122_0458"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="billing",
            options={"ordering": ["billing_year", "-billing_month"]},
        ),
    ]
