# Generated by Django 1.9.5 on 2016-06-05 19:25

import django.db.models.deletion
import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("member", "0001_fix161f"),
    ]

    operations = [
        migrations.CreateModel(
            name="Notification",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("description", models.TextField(verbose_name="description")),
                ("date", models.DateField(default=django.utils.timezone.now)),
                (
                    "member",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="member.Member",
                        verbose_name="member",
                    ),
                ),
            ],
            options={
                "verbose_name_plural": "notifications",
            },
        ),
    ]
