{% load i18n %}

<div class="ui basic modal billing-{{billing.id}}">
  <div class="ui icon header">
      <i class="trash icon"></i>
      {% trans "Delete Billing" %} {{billing.billing_year}}/{{billing.billing_month}}
    </div>
  <div class="content" style="text-align:center;">
      <p>{% trans 'This billing will be deleted. No orders will be deleted, no worry. Are you sure?' %}</p>
  </div>
  <div class="actions">
    <form action="{% url 'billing:delete' pk=billing.id %}?next={% url 'billing:list' %}%3F{{request.META.QUERY_STRING|urlencode}}" method="POST" id="billing-{{billing.id}}-delete-form">{% csrf_token %}
       <div class="ui red cancel button"> <i class="remove icon"></i> {% trans "No" %} </div>
       <button class="ui green button" type="submit"> <i class="checkmark icon"></i> {% trans "Yes" %} </button>
   </form>
     </div>
 </div>
