# Generated by Django 1.10.6 on 2017-04-19 15:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("note", "0010_auto_20170313_1442"),
    ]

    operations = [
        migrations.AlterField(
            model_name="note",
            name="category",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="notes",
                to="note.NoteCategory",
                verbose_name="Category",
            ),
        ),
        migrations.AlterField(
            model_name="note",
            name="priority",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="notes",
                to="note.NotePriority",
                verbose_name="Priority",
            ),
        ),
    ]
