# Generated by Django 1.10 on 2016-11-30 20:00

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("order", "0012_auto_20161122_0458"),
    ]

    operations = [
        migrations.CreateModel(
            name="OrderStatusChange",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "status_from",
                    models.CharField(
                        choices=[
                            ("O", "Ordered"),
                            ("D", "Delivered"),
                            ("N", "No Charge"),
                            ("C", "Cancelled"),
                            ("B", "Billed"),
                            ("P", "Paid"),
                        ],
                        max_length=1,
                    ),
                ),
                (
                    "status_to",
                    models.CharField(
                        choices=[
                            ("O", "Ordered"),
                            ("D", "Delivered"),
                            ("N", "No Charge"),
                            ("C", "Cancelled"),
                            ("B", "Billed"),
                            ("P", "Paid"),
                        ],
                        max_length=1,
                    ),
                ),
                ("reason", models.CharField(blank=True, default="", max_length=200)),
                ("change_time", models.DateTimeField(auto_now_add=True)),
                (
                    "order",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="status_changes",
                        to="order.Order",
                    ),
                ),
            ],
            options={
                "ordering": ["change_time"],
            },
        ),
    ]
